Module prelude

Module prelude 

Common electronics primitive types from the focused crates.

Structs

BoardName
A non-empty board name.
CapacitanceValue
A capacitance value in farads.
CapacitorSpec
A descriptive capacitor specification.
ComponentValue
A descriptive component value such as 10k, 100nF, or STM32F4.
Connection
A descriptive connection from a terminal to a net or node.
CurrentRating
A current rating in amperes.
DiodeSpec
A descriptive diode specification.
FrequencyRating
A frequency rating in hertz.
LayerCount
A non-zero board layer count.
NetId
A net identifier.
NetLabel
A non-empty net label.
NodeId
A circuit node identifier.
PackageName
A non-empty package name such as DIP-8, SOIC-16, TO-220, or 0603.
PackagePitch
A simple package pitch value in millimeters.
PinCount
A non-zero package pin count.
PinName
A descriptive pin name such as VCC, GND, SDA, or RESET.
PinNumber
A one-based package or component pin number.
PinRef
A reference to a component pin, such as U2:VCC or R1:1.
PowerRail
A descriptive power rail label such as VCC, 3V3, or VIN.
PowerRating
A power rating in watts.
ReferenceDesignator
A reference designator such as R1, C4, U2, D3, J1, or SW1.
ResistanceValue
A resistance value in ohms.
ResistorSpec
A descriptive resistor specification.
SignalName
A descriptive signal name such as SDA, SCL, CLK, or RESET.
TemperatureRating
A temperature rating in degrees Celsius.
Terminal
A component terminal represented as a component pin reference.
Tolerance
A tolerance value in percent.
TransistorSpec
A descriptive transistor specification.
VoltageRating
A voltage rating in volts.

Enums

BjtKind
Bipolar junction transistor kind.
BoardLayer
Simple board layer vocabulary.
BoardSide
Board side vocabulary.
CapacitorKind
Descriptive capacitor kind vocabulary.
CapacitorPolarity
Descriptive capacitor polarity vocabulary.
ComponentKind
A small electronic component classification vocabulary.
DiodeKind
Descriptive diode kind vocabulary.
DiodePolarity
Diode terminal polarity vocabulary.
FetKind
Field-effect transistor kind.
GroundKind
Common ground label vocabulary.
PackageKind
Common electronic package families.
PinPolarity
Descriptive pin polarity vocabulary.
PinRole
Descriptive electronic pin roles.
ResistorKind
Descriptive resistor kind vocabulary.
TransistorKind
Descriptive transistor kind vocabulary.
TransistorTerminal
Transistor terminal vocabulary.