pub struct NetLabel(/* private fields */);Expand description
A non-empty net label.
Implementations
Sourceimpl NetLabel
impl NetLabel
Sourcepub fn new(value: impl AsRef<str>) -> Result<NetLabel, TextLabelError>
pub fn new(value: impl AsRef<str>) -> Result<NetLabel, TextLabelError>
Creates a net label from non-empty text.
Errors
Returns TextLabelError::Empty when the trimmed value is empty.
Sourcepub fn is_ground(&self) -> bool
pub fn is_ground(&self) -> bool
Returns whether this label is one of the obvious common ground labels.
Sourcepub fn is_power_like(&self) -> bool
pub fn is_power_like(&self) -> bool
Returns whether this label is one of the obvious common power-like labels.